@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
+from venv import logger
 
 from pydantic import BaseModel
 
@@ -23,10 +24,11 @@ class TaskSet(BaseModel):
         description: Description of the taskset
         tasks: List of Task objects in the taskset
     """
+
     id: str | None = None
     description: str | None = None
     tasks: list[Task] = []
-    
+
     def __getitem__(self, index: int) -> Task:
         """
         Allows accessing tasks by index using square bracket notation.
@@ -41,7 +43,7 @@ class TaskSet(BaseModel):
             IndexError: If the index is out of range
         """
         return self.tasks[index]
-    
+
     def __len__(self) -> int:
         """
         Returns the number of tasks in the taskset.
@@ -50,14 +52,40 @@ class TaskSet(BaseModel):
             int: The number of tasks in the taskset
         """
         return len(self.tasks)
-    
+
     def __iter__(self) -> Iterator[Task]:
         """
         Returns an iterator over the tasks in the taskset.
         """
         return iter(self.tasks)
 
-    
+    async def upload(
+        self,
+        name: str,
+        description: str | None = None,
+        api_key: str | None = None,
+    ) -> None:
+        """
+        Uploads the taskset to the server.
+        """
+        if api_key is None:
+            api_key = settings.api_key
+
+        await make_request(
+            method="POST",
+            url=f"{settings.base_url}/v2/tasksets",
+            api_key=api_key,
+            json={
+                "name": name,
+                "description": description,
+                "tasks": [task.model_dump() for task in self.tasks],
+            },
+        )
+        logger.info(
+            "[HUD] Taskset %s uploaded successfully, see it on app.hud.so/tasksets/%s", name, name
+        )
+
+
 async def load_taskset(taskset_id: str, api_key: str | None = None) -> TaskSet:
     """
     Loads a TaskSet by its ID.
@@ -69,20 +97,25 @@ async def load_taskset(taskset_id: str, api_key: str | None = None) -> TaskSet:
     Returns:
         TaskSet: The loaded taskset
     """
-    
+
     if api_key is None:
         api_key = settings.api_key
-    
+
     data = await make_request(
         method="GET",
         url=f"{settings.base_url}/v2/tasksets/{taskset_id}/tasks",
         api_key=api_key,
     )
-    
-    return TaskSet.model_validate({
-        "id": taskset_id,
-        "tasks": data["evalset"],
-    })
+
+    logger.info(f"[HUD] Taskset {taskset_id} loaded successfully")
+
+    return TaskSet.model_validate(
+        {
+            "id": taskset_id,
+            "tasks": data["evalset"],
+        }
+    )
+
 
 def load_from_inspect(dataset: Dataset) -> TaskSet:
     """
