@@ -2,8 +2,12 @@ from __future__ import annotations
 
 import logging
 import re
+from typing import TYPE_CHECKING
 
-from hud.utils.common import HudStyleConfig, HudStyleConfigs
+from hud.utils.common import FunctionConfig, FunctionConfigs
+
+if TYPE_CHECKING:
+    from typing import TypeGuard
 
 logger = logging.getLogger("hud.utils.config")
 
@@ -11,22 +15,27 @@ REMOTE_FUNCTION_PREFIX = "private_"
 REMOTE_SETUP = "setup"
 REMOTE_EVALUATE = "evaluate"
 
+LOCAL_EVALUATORS = ["response_is", "response_includes", "response_match"]
+
+
 def _is_valid_python_name(name: str) -> bool:
     """Check if a string is a valid Python identifier."""
     return bool(re.match(r"^[a-zA-Z_][a-zA-Z0-9_]*$", name))
 
-def _validate_hud_config(config: dict) -> HudStyleConfig:
-    """Validate and convert a dictionary to an HudStyleConfig."""
+
+def _validate_hud_config(config: dict) -> FunctionConfig:
+    """Validate and convert a dictionary to an FunctionConfig."""
     if not isinstance(config.get("function"), str):
         raise ValueError("function must be a string")
-    
+
     # Validate function path components
     _split_and_validate_path(config["function"])
 
     args = config["args"] if isinstance(config.get("args"), list) else [config["args"]]
-    
-    # Create a proper HudStyleConfig object instead of using cast
-    return HudStyleConfig(function=config["function"], args=args, id=config.get("id"))
+
+    # Create a proper FunctionConfig object instead of using cast
+    return FunctionConfig(function=config["function"], args=args, id=config.get("id"))
+
 
 def _split_and_validate_path(path: str) -> None:
     """Split a function path into components, validating each part."""
@@ -34,46 +43,52 @@ def _split_and_validate_path(path: str) -> None:
 
     if not parts:
         raise ValueError("Empty function path")
-    
+
     # Validate each part
     for part in parts:
         if not _is_valid_python_name(part):
             raise ValueError(f"Invalid Python identifier in path: {part}")
 
-def expand_config(config: HudStyleConfigs) -> list[HudStyleConfig]:
+
+def _is_list_of_configs(config: FunctionConfigs) -> TypeGuard[list[FunctionConfig]]:
+    """Check if a config is a list of FunctionConfig objects."""
+    return isinstance(config, list) and all(isinstance(item, FunctionConfig) for item in config)
+
+
+def expand_config(config: FunctionConfigs) -> list[FunctionConfig]:
     """
-    Process a config into a standardized list of HudStyleConfig objects.
-    
+    Process a config into a standardized list of FunctionConfig objects.
+
     Args:
         config: Can be:
             - A tuple where first element is function name and rest are args
-            - A HudStyleConfig object
+            - A FunctionConfig object
             - A dictionary with "function" and "args" keys
-            - A list of HudStyleConfig objects
-            
+            - A list of FunctionConfig objects
+
     Returns:
-        list[HudStyleConfig]: List of standardized configurations
-        
+        list[FunctionConfig]: List of standardized configurations
+
     Raises:
         ValueError: If the configuration format is invalid
     """
     logger.debug("Processing config: %s", config)
 
-    # If it's already a HudStyleConfig, just wrap it in a list
-    if isinstance(config, HudStyleConfig):
+    # If it's already a FunctionConfig, just wrap it in a list
+    if isinstance(config, FunctionConfig):
         return [config]
-    
-    # If it's a list of HudStyleConfigs, return as is
-    if isinstance(config, list) and all(isinstance(item, HudStyleConfig) for item in config):
-        return config # type: ignore
-    
+
+    # If it's a list of FunctionConfigs, return as is
+    if _is_list_of_configs(config):
+        return config
+
     # Handle dictionary configuration
     if isinstance(config, dict):
         return [_validate_hud_config(config)]
-    
+
     if isinstance(config, str):
-        return [HudStyleConfig(function=config, args=[])]
-    
+        return [FunctionConfig(function=config, args=[])]
+
     # Handle tuple format
     if isinstance(config, tuple):
         if len(config) < 1 or not isinstance(config[0], str):
@@ -81,13 +96,13 @@ def expand_config(config: HudStyleConfigs) -> list[HudStyleConfig]:
             "Expected tuple[str, ...], got: {type(config)}"
             logger.error(error_msg)
             raise ValueError(error_msg)
-        
+
         # First element is the function name, rest are args
         function_name = config[0]
         args = list(config[1:]) if len(config) > 1 else []
-        
-        return [HudStyleConfig(function=function_name, args=args)]
-    
+
+        return [FunctionConfig(function=function_name, args=args)]
+
     # Unknown configuration type
     error_msg = f"Unknown configuration type: {type(config)}"
     logger.error(error_msg)
